function [EEG, command] = pop_loadcurry(fullfilename, varargin)
%   Import a Neuroscan Curry file into EEGLAB. Currently supports Curry6
%   and Curry7 data files.
%
%   Input Parameters:
%        1    Specify the filename of the Curry file (extension should be either .dap, .dat, or .rs3). 
%
%   Example Code:
%
%       >> EEG = pop_loadcurry;   % an interactive uigetfile window
%       >> EEG = pop_loadcurry('C:\Studies\File1.dap');    % no pop-up window 
%       >> EEG = loadcurry('C:\Studies\File1.dap');    % no pop-up window 
%
%   Author for reading into Matlab: Neuroscan 
%   Author for translating to EEGLAB: Matthew B. Pontifex, Health Behaviors and Cognition Laboratory, Michigan State University, August 26, 2015

    command = '';
    if nargin < 1 % No file was identified in the call

        [filename, filepath] = uigetfile('*.dap;*.DAP;*.rs3;*.RS3', 'Choose a Neuroscan Curry file -- pop_loadcurry()'); 
        drawnow;
        if filename == 0 % the user aborted
            error('pop_loadcurry(): File selection cancelled. Error thrown to avoid overwriting data in EEG.')
            
        else % The user selected something
            
            % Get filename components
            [pathstr,name,ext] = fileparts([filepath, filename]);
            fullfilename = [filepath, filename];
            file = [pathstr, filesep, name];
            
            % Ensure the appropriate file types exist under that name
            boolfiles = 1;
            if (exist([file '.dap'], 'file') == 0) || (exist([file '.dat'], 'file') == 0) || (exist([file '.rs3'], 'file') == 0)
                boolfiles = 0;
                error('Error in pop_loadcurry(): The requested filename "%s" in "%s" does not have all three file components (.dap, .dat, .rs3) created by Curry.', name, filepath)
            end
            if (boolfiles == 1) % All files exist
                EEG = [];
                EEG = eeg_emptyset;
                [EEG, command] = loadcurry(fullfilename);
            else
                return % should be impossible to occur
            end
            
            % Show user the direct call equivalent
            command = sprintf('\nEquivalent Command:\n\tEEG = loadcurry(''%s%s'');',filepath, [name '.dap']);
            disp(command)
        end

    else % file was specified in the call
        
        EEG = [];
        EEG = eeg_emptyset;
        [EEG, command] = loadcurry(fullfilename);
    end
        
end

